@@ -19,7 +19,7 @@
 #define PARQUET_API_WRITER_H
 
 // Column reader API
-#include "parquet/column/writer.h"
+#include "parquet/column_writer.h"
 #include "parquet/exception.h"
 #include "parquet/file/writer.h"
 
