@@ -3,13 +3,8 @@
 set -e
 set -x
 
-# Build dependencies
-export BOOST_ROOT=$PREFIX
-export SNAPPY_HOME=$PREFIX
-export THRIFT_HOME=$PREFIX
-export ZLIB_HOME=$PREFIX
-export BROTLI_HOME=$PREFIX
-export PARQUET_ARROW_VERSION=a8f8ba0cbcf5f596f042e90b7a208e7a0c3925b7
+export PARQUET_BUILD_TOOLCHAIN=$PREFIX
+export PARQUET_ARROW_VERSION=e9f76e125b836d0fdc0a533e2fee3fca8bf4c1a1
 
 mkdir build-dir
 cd build-dir
@@ -18,11 +13,9 @@ cmake \
     -DCMAKE_BUILD_TYPE=release \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
     -DCMAKE_INSTALL_LIBDIR=$PREFIX/lib \
-    -DPARQUET_ARROW=on \
     -DPARQUET_BOOST_USE_SHARED=off \
     -DPARQUET_BUILD_BENCHMARKS=off \
     -DPARQUET_BUILD_EXECUTABLES=off \
-    -DPARQUET_ZLIB_VENDORED=off \
     -DPARQUET_BUILD_TESTS=off \
     ..
 
